==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/entities/spiderBlobs.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void faceLocation(Unit *unit, Vector location);
extern void faceTarget(Unit *unit);
extern void attackTarget(Unit *unit);
extern void attackTargetScatter(Unit *unit);
extern bool enemySightTarget(Unit *unit, int range);
extern void enemyMoveToTarget(Unit *unit);
extern void throwExplosionDebris(Vector position);
extern void throwFleshChunk(Vector position, bool underWater);
extern void throwSpawnedItem(Entity *item);
extern void doExplosion(Vector position, int size, Entity *owner);
extern void addEnemy(int enemyId, Vector position);
extern void addTeleportParticles(Vector position);
extern Weapon *addWeapon(Properties *props);
extern Item *addItem(Properties *props);
extern int getSoundDistanceFromPlayer(Vector position);
extern void addHelperItems(int numberOfWeapon, WeaponDef *weaponDef, Vector position);
extern WeaponDef *getRandomPlayerAmmoType();
extern int getAdjustedHealthChance(int in, int minimum);
extern void addBloodSplat(Vector position, float size);
extern void addGeneralDebris(Vector position, Vector velocity, float health, char *textureName, float size, bool slides);
extern void addDebrisEmitter(Vector position);
extern void fireWeapon(Unit *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void addLauncherShot(Entity *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addWeb(Entity *owner, Vector origin, Vector destination);
extern void bioMechSearch();
extern Vector getLeadingTargetPosition(Entity *attacker, Entity *target);
extern void generalMechLargeExplosion();
extern void generalBlobDeathSplat();
extern void addSmokeParticle(Vector position);
extern void throwFleshChunk(Vector position, bool underWater);
extern void getAnimation(char *name, Entity *ent);
extern void generalDroidDie();
extern Bullet *addGrapplingHook(Entity *owner, Vector destination);
extern Vector getGunPosition(Unit *unit, int i);

extern Audio *audio;
extern Camera *camera;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern RandomNameGenerator *randomNameGenerator;
extern Unit *player;

extern Entity *self;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/entities/spiderBlobs.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void faceLocation(Unit *unit, Vector location);
extern void faceTarget(Unit *unit);
extern void attackTarget(Unit *unit);
extern void attackTargetScatter(Unit *unit);
extern bool enemySightTarget(Unit *unit, int range);
extern void enemyMoveToTarget(Unit *unit);
extern void throwExplosionDebris(Vector position);
extern void throwFleshChunk(Vector position, bool underWater);
extern void throwSpawnedItem(Entity *item);
extern void doExplosion(Vector position, int size, Entity *owner);
extern void addEnemy(int enemyId, Vector position);
extern void addTeleportParticles(Vector position);
extern Weapon *addWeapon(Properties *props);
extern Item *addItem(Properties *props);
extern int getSoundDistanceFromPlayer(Vector position);
extern void addHelperItems(int numberOfWeapon, WeaponDef *weaponDef, Vector position);
extern WeaponDef *getRandomPlayerAmmoType();
extern int getAdjustedHealthChance(int in, int minimum);
extern void addBloodSplat(Vector position, float size);
extern void addGeneralDebris(Vector position, Vector velocity, float health, const char *textureName, float size, bool slides);
extern void addDebrisEmitter(Vector position);
extern void fireWeapon(Unit *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void addLauncherShot(Entity *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addWeb(Entity *owner, Vector origin, Vector destination);
extern void bioMechSearch();
extern Vector getLeadingTargetPosition(Entity *attacker, Entity *target);
extern void generalMechLargeExplosion();
extern void generalBlobDeathSplat();
extern void addSmokeParticle(Vector position);
extern void throwFleshChunk(Vector position, bool underWater);
extern void getAnimation(const char *name, Entity *ent);
extern void generalDroidDie();
extern Bullet *addGrapplingHook(Entity *owner, Vector destination);
extern Vector getGunPosition(Unit *unit, int i);

extern Audio *audio;
extern Camera *camera;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Map *map;
extern Mission *mission;
extern RandomNameGenerator *randomNameGenerator;
extern Unit *player;

extern Entity *self;
